"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var getFileDocumentation_1 = require("../getFileDocumentation");
describe('getFileDocumentation', function () {
    it('Should parse class-based components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Column.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Column', c.name);
        chai_1.assert.equal('Form column.', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse class-based components (2)', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/AppMenu.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('AppMenu', c.name);
        chai_1.assert.equal('App Menu Component', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IAppMenuProps', i.name);
        chai_1.assert.equal('App Menu Props', i.comment);
        chai_1.assert.equal(1, i.members.length);
        chai_1.assert.equal('menu', i.members[0].name);
        chai_1.assert.equal('Menu items', i.members[0].comment);
    });
    it('Should parse class-based components with unexported props interface', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnWithoutExportedProps.tsx'); // it's running in ./temp    
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Column', c.name);
        chai_1.assert.equal('Form column.', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IColumnProps', i.name);
        chai_1.assert.equal('Column properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse functional components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Row.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('StatelessComponent', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse class-based pure components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/PureRow.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('PureComponent', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should avoid parsing exported objects as components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ConstExport.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Row', c.name);
        chai_1.assert.equal('Form row.', c.comment);
        chai_1.assert.equal('StatelessComponent', c.extends);
        chai_1.assert.isNotNull(c);
        var i = c.propInterface;
        chai_1.assert.equal('IRowProps', i.name);
        chai_1.assert.equal('Row properties.', i.comment);
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal('prop1', i.members[0].name);
        chai_1.assert.equal('prop1 description', i.members[0].comment);
        chai_1.assert.equal(false, i.members[0].isRequired);
        chai_1.assert.equal('prop2', i.members[1].name);
        chai_1.assert.equal('prop2 description', i.members[1].comment);
        chai_1.assert.equal(true, i.members[1].isRequired);
        chai_1.assert.equal('prop3', i.members[2].name);
        chai_1.assert.equal('prop3 description', i.members[2].comment);
        chai_1.assert.equal(true, i.members[2].isRequired);
        chai_1.assert.equal('prop4', i.members[3].name);
        chai_1.assert.equal('prop4 description', i.members[3].comment);
        chai_1.assert.equal(true, i.members[3].isRequired);
    });
    it('Should parse higher order components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnHigherOrderComponent.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(6, result.components.length);
        var r1 = result.components[0];
        chai_1.assert.equal('ColumnHigherOrderComponent1', r1.name);
        chai_1.assert.equal('ColumnHigherOrderComponent1 specific comment', r1.comment);
        chai_1.assert.equal('Column', r1.extends);
        chai_1.assert.isNotNull(r1.propInterface);
        var p1 = r1.propInterface;
        chai_1.assert.equal('IColumnProps', p1.name);
        chai_1.assert.equal('Column properties.', p1.comment);
        chai_1.assert.equal(4, p1.members.length);
        chai_1.assert.equal('prop1', p1.members[0].name);
        chai_1.assert.equal('prop1 description', p1.members[0].comment);
        chai_1.assert.equal(false, p1.members[0].isRequired);
        chai_1.assert.equal('prop2', p1.members[1].name);
        chai_1.assert.equal('prop2 description', p1.members[1].comment);
        chai_1.assert.equal(true, p1.members[1].isRequired);
        chai_1.assert.equal('prop3', p1.members[2].name);
        chai_1.assert.equal('prop3 description', p1.members[2].comment);
        chai_1.assert.equal(true, p1.members[2].isRequired);
        chai_1.assert.equal('prop4', p1.members[3].name);
        chai_1.assert.equal('prop4 description', p1.members[3].comment);
        chai_1.assert.equal(true, p1.members[3].isRequired);
        var r2 = result.components[1];
        chai_1.assert.equal('ColumnHigherOrderComponent2', r2.name);
        chai_1.assert.equal('Form column.', r2.comment);
        chai_1.assert.equal('Column', r2.extends);
        chai_1.assert.isNotNull(r2.propInterface);
        var p2 = r2.propInterface;
        chai_1.assert.equal('IColumnProps', p2.name);
        var r3 = result.components[2];
        chai_1.assert.equal('ColumnExternalHigherOrderComponent', r3.name);
        chai_1.assert.equal('Form column.', r3.comment);
        chai_1.assert.equal('Column', r3.extends);
        chai_1.assert.isNotNull(r3.propInterface);
        var p3 = r3.propInterface;
        chai_1.assert.equal('IColumnProps', p3.name);
        var r4 = result.components[3];
        chai_1.assert.equal('RowHigherOrderComponent1', r4.name);
        chai_1.assert.equal('RowHigherOrderComponent1 specific comment', r4.comment);
        chai_1.assert.equal('Row', r4.extends);
        chai_1.assert.isNotNull(r4.propInterface);
        var p4 = r4.propInterface;
        chai_1.assert.equal('IRowProps', p4.name);
        var r5 = result.components[4];
        chai_1.assert.equal('RowHigherOrderComponent2', r5.name);
        chai_1.assert.equal('Form row.', r5.comment);
        chai_1.assert.equal('Row', r5.extends);
        chai_1.assert.isNotNull(r5.propInterface);
        var p5 = r5.propInterface;
        chai_1.assert.equal('IRowProps', p5.name);
        var r6 = result.components[5];
        chai_1.assert.equal('RowExternalHigherOrderComponent', r6.name);
        chai_1.assert.equal('Form row.', r6.comment);
        chai_1.assert.equal('Row', r6.extends);
        chai_1.assert.isNotNull(r6.propInterface);
        var p6 = r6.propInterface;
        chai_1.assert.equal('IRowProps', p6.name);
    });
});
//# sourceMappingURL=getFileDocumentation.spec.js.map